from bson.json_util import dumps
from bson.json_util import loads

from transformHealthEventHubModels.utils import *


class DataStandardisationTriggerObject(object):

    def __init__(self, file_id, client_id, upload_file_name, template_id, upload_file_location, file_source, share_name):
        self.file_id = file_id
        self.clientID = client_id
        self.uploadFileName = upload_file_name
        self.templateId = template_id
        self.uploadFileLocation = upload_file_location
        self.fileSource = file_source
        self.shareName = share_name

    def json(self):
        return {
            "file_id": dumps(self.file_id, sort_keys=True, default=str),
            "client_id": dumps(self.clientID, sort_keys=True, default=str),
            "upload_file_name": self.uploadFileName,
            "template_id": dumps(self.templateId, sort_keys=True, default=str),
            "upload_file_location": self.uploadFileLocation,
            "file_source": self.fileSource,
            "share_name": self.shareName
        }

    @classmethod
    def load_object(cls, json_data):
        return cls(
            loads(decodeUTFString(json_data[b'file_id'])),
            loads(decodeUTFString(json_data[b'client_id'])),
            decodeUTFString(json_data[b'upload_file_name']),
            loads(decodeUTFString(json_data[b'template_id'])),
            decodeUTFString(json_data[b'upload_file_location']),
            decodeUTFString(json_data[b'file_source']),
            decodeUTFString(json_data[b'share_name'])
        )



from bson.json_util import dumps
from bson.json_util import loads
from transformHealthEventHubModels.utils import *


class DSEventHubUpdateOneObject(object):
    def __init__(self, collection, filter_condition, operation, upsert=False, array_filters=None, uniqueness_key_and=None, uniqueness_key_or=None):
        self.collection = collection
        self.filter_condition = filter_condition
        self.operation = operation
        self.upsert = upsert
        self.array_filters = array_filters
        self.uniqueness_key_and = uniqueness_key_and
        self.uniqueness_key_or = uniqueness_key_or

    def json(self):
        return {
            "collection": self.collection,
            "filter_condition": dumps(self.filter_condition),
            "operation": dumps(self.operation),
            "upsert": str(self.upsert),
            "array_filters": dumps(self.array_filters),
            "uniqueness_key_and": self.uniqueness_key_and,
            "uniqueness_key_or": self.uniqueness_key_or
        }

    @classmethod
    def load_object(cls, json_object):
        return cls(
            decodeUTFString(json_object[b"collection"]),
            loads(decodeUTFString(json_object[b"filter_condition"])),
            loads(decodeUTFString(json_object[b"operation"])),
            decodeUTFString(json_object[b"upsert"]) == "True",
            loads(decodeUTFString(json_object[b"array_filters"])),
            loads(decodeUTFString(json_object[b"uniqueness_key_and"])),
            loads(decodeUTFString(json_object[b"uniqueness_key_or"]))

        )



import json
import re

from dateutil import parser


def date_string(string):
    return re.search("^[0-9]{4}-[0-9]{2}-[0-9]{2} [0-9]{2}:[0-9]{2}:[0-9]{2}", string)


def decodeUTFString(encoded_string):
    return encoded_string.decode('UTF-8')


def type_corrected_json_load(encoded_string):
    decoded_dict = json.loads(decodeUTFString(encoded_string))
    for (key, value) in decoded_dict.items():
        if isinstance(value, str) and date_string(value):
            decoded_dict[key] = parser.parse(value)
    return decoded_dict



from bson.json_util import dumps
from bson.json_util import loads

from transformHealthEventHubModels.utils import *


class DSEventHubInsertOneObject(object):
    def __init__(self, collection, data, uniqueness_key_and=None, uniqueness_key_or=None):
        self.collection = collection
        self.data = data,
        self.uniqueness_key_and = uniqueness_key_and
        self.uniqueness_key_or = uniqueness_key_or

    def json(self):
        return {
            "collection": self.collection,
            "data": dumps(self.data, sort_keys=True, default=str),
            "uniqueness_key_and": self.uniqueness_key_and,
            "uniqueness_key_or": self.uniqueness_key_or
        }

    @classmethod
    def load_object(cls, json_data):
        data = decodeUTFString(json_data[b'data'])
        return cls(
            decodeUTFString(json_data[b'collection']),
            loads(data),
            decodeUTFString(json_data[b'uniqueness_key_and']),
            decodeUTFString(json_data[b'uniqueness_key_or'])
        )
